#
# spec file for package golang
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2011 Sascha Peilicke <saschpe@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global provider        github
%global provider_tld    com
%global project         golang
%global repo            protobuf
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}

Name:           golang-%{provider}-%{project}-%{repo}
Version:        0.0.0+git20170217.69b215d
Release:        5.1
Summary:        Go support for Protocol Buffers - Google's data interchange format
License:        BSD-3-Clause
Group:          Development/Languages/Golang
Url:            https://%{provider_prefix}
Source0:        %{repo}-%{version}.tar.xz
Source1:        rpmlintrc
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  golang-packaging
BuildRequires:  xz

BuildRequires:  golang(golang.org/x/sync/errgroup)
Requires:       golang(golang.org/x/sync/errgroup)

%{go_nostrip}
%{go_provides}

%description
This package provides Go support, in the form of a library and protocol compiler
plugin, for Google's protocol buffers. (RPC is not supported.)

%package -n protoc-gen-go
Summary:        Go support for Protocol Buffers - Google's data interchange format
Group:          Development/Languages/Golang
AutoReqProv:    Off

%{go_exclusivearch}

%description -n protoc-gen-go
This package provides Go support, in the form of a library and protocol compiler
plugin, for Google's protocol buffers. (RPC is not supported.)

%prep
%setup -q -n %{repo}-%{version}

%build
%goprep %{import_path}
%gobuild ...

%install
%goinstall
%gosrc
%gofilelist

%check
%gotest %{import_path}...

%files -f file.lst
%defattr(-,root,root,-)
%doc README.md LICENSE AUTHORS CONTRIBUTORS

%files -n protoc-gen-go
%defattr(-,root,root)
%{_bindir}/protoc-gen-go

%changelog
* Wed Mar  1 2017 thipp@suse.de
- Update to version 0.0.0+git20170217.69b215d:
  * protoc-gen-go: Add Filename to ExtensionDesc.
  * Regenerate pb.go files after https://github.com/golang/protobuf/commit/24f28ae800abfde9310e779f94be606b1a98a3fc
  * Add a benchmark demonstrating lock contention when Marshaling/Unmarshaling maps.
  * Generate pb.go files after https://github.com/golang/protobuf/commit/cb9b7771abc2a63ab206dde76539f08f66ab994d
  * jsonpb: treat `null` JSON values for `Timestamp` and `Duration` as defaults (#255)
  * proto: Fix a Marshal race on messages with extensions.
  * proto: Add a descriptor subpackage.
  * jsonpb: merge https://github.com/golang/protobuf/pull/255
  * descriptor: rename generated protobuf package on import.
  * fix import path
- Update rpmlintrc
- Update requirements
* Thu Dec  8 2016 tboerger@suse.com
- Update to version 0.0.0+git20161116.8ee7999:
  * Run 'make generate-test-pbs' in proto/ to regenerate proto3.pb.go testdata
  * protoc-gen-go: Add Filename to ExtensionDesc.
  * Regenerate pb.go files after https://github.com/golang/protobuf/commit/24f28ae800abfde9310e779f94be606b1a98a3fc
  * Add a benchmark demonstrating lock contention when Marshaling/Unmarshaling maps.
  * Generate pb.go files after https://github.com/golang/protobuf/commit/cb9b7771abc2a63ab206dde76539f08f66ab994d
  * jsonpb: treat `null` JSON values for `Timestamp` and `Duration` as defaults (#255)
  * proto: Fix a Marshal race on messages with extensions.
  * proto: Add a descriptor subpackage.
  * jsonpb: merge https://github.com/golang/protobuf/pull/255
  * descriptor: rename generated protobuf package on import.
* Thu Dec  8 2016 tboerger@suse.com
- Renamed the subpackage for the protoc-gen-go binary
* Wed Aug 17 2016 tboerger@suse.com
- Refactoed spec with a new unified layout
- Added rpmlintrc for common golang linting
* Sun Apr  3 2016 i@marguerite.su
- add xz dependency for SLE
- get rid of -source subpackage, no one use it
* Sat Dec 26 2015 matwey.kornilov@gmail.com
- Update to version 0.0.0+git20151207.68415e7:
  + Unexport proto.MessageSet, and remove a bunch of its support.
  + Add compressed file descriptor code generation.
  + Remove a test that has outlived its usefulness.
  + Generate correct service name for gRPC services without a package name.
  + Document parameters in README
  + Fix unmarshaling code to properly handle multiple instances of the same extension appearing in the wire format. Prior to this change, multiple custom options would result in all but the first being discarded when processed using the proto.GetExtension() facilities.
  + Regenerate protos.
  + Generate sizer functions for oneofs.
  + By popular demand, rename README to README.md and make Markdown consistent.
  + Add some more Markdown annotations.
* Sat Jul 11 2015 i@marguerite.su
- rename golang-github-golang-protobuf
- update version 0.0.0+git20150708.ab974be
- use golang-packaging for packaging
* Sat Mar 21 2015 i@marguerite.su
- remove go_disable_brp_strip_static_archive usage
- name changed to go-protobuf
- source changed from google code to github.com/golang/protobuf
- version update to 0.0.0+git20150320.de8c523
* Mon Aug  5 2013 ro@suse.de
- use ExclusiveArch to limit build to the same architectures as go
* Sat Jun 29 2013 graham@andtech.eu
- Update pacakge to latest upstream mercurial version
* Mon Jun 11 2012 graham@andtech.eu
- Update spec with new package path locations
- Add documentation sub-package
* Thu Feb 16 2012 graham@andtech.eu
- Update for weekly 2012-02-12
- Remove uses of runtime.MemStats.
- Correctly generate extension names for .proto files that don't declare a
  package.
- Better error handling for invalid input that mentions tag 0.
- Weak import/field handling.
- Fix proto.Equal to consider empty and nil repeated fields as equal.
- Avoid generating a struct that uses the same name for a field and a method.
- update to loss of unsafe.Unreflect, unsafe.New
* Wed Feb  8 2012 graham@andtech.eu
- patch for encode/decode update runtime.MemStats use for weekly
* Wed Jan 25 2012 graham@andtech.eu
- Update for weekly.2012-01-20
- update to go 1 import strings
- Fix panic in SetDefaults for nil sub-messages
- Fix a couple of instances where bad input could cause a panic
- GetExtension now returns a specific error when the requested extension is
  missing
* Wed Dec 14 2011 saschpe@suse.de
- Adjust to Go weekly.2011-12-02 changes
* Thu Sep  8 2011 saschpe@suse.de
- Update to 08/09/2011 mercurial version:
  * Follow changes of weekly Go release
* Fri Jun 24 2011 saschpe@gmx.de
- Update to 24/06/2011 mercurial version
  * goprotobuf: update for Alignof/Sizeof returning uintptr, and
    goto restriction
  * goprotobuf: sync from Google internal version
* Tue Jun 14 2011 saschpe@gmx.de
- Update to 14/06/2011 mercurial release
  * Adapted reflect API changes
  * Safer unmarshalling
- Added goprotobuf-fix-imports patch
- Added goprotobuf-fix-proto-testsuite patch
- Also build and install goproto-gen-go binary
- Use new %%go_disable_brp_strip_static_archive macro
* Sat May 21 2011 saschpe@gmx.de
- Switch to %%{go_make_test} macro
* Fri May 20 2011 saschpe@suse.de
- Use Go RPM macros instead of custom ones
- Use proper package versioning scheme (needs reinstall)
- Drop provides/obsoletes of old package, needs reinstall anyway
* Thu May 19 2011 saschpe@suse.de
- Remove rpmlintrc, not needed anymore
* Thu May 19 2011 saschpe@suse.de
- Simpler build
* Wed May 18 2011 saschpe@suse.de
- Don't require 'go'
- Disable brp-strip-static-archive on Fedora, breaks build
- Provide devel and devel-static packages
- Remove devel-file-in-non-devel-package rpmlint filter
* Mon Mar 21 2011 saschpe@suse.de
- Removed authors from description
- Removed pkg_version macro, use %%%%{version} directly
* Wed Mar  9 2011 graham@andtech.eu
- Updated to 09/03/2001 upstream
* Thu Feb  3 2011 graham@andtech.eu
- Updated to 01/02/2011 upstream
* Thu Dec  2 2010 speilicke@novell.com
- Updated to 02/12/2010 upstream version
* Tue Nov 16 2010 speilicke@novell.com
- Updated to 16/11/2010 upstream version
* Tue Nov  9 2010 speilicke@novell.com
- Initial commit
